package com.jz.dmp.modules.controller;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.annotation.MethodCallLogPrint;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.bean.DmpNavigationTreeDto;
import com.jz.dmp.modules.controller.bean.DmpNavigationTreeRequest;
import com.jz.dmp.modules.model.DmpNavigationTree;
import com.jz.dmp.modules.service.DmpNavigationTreeService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * DMP资源导航树(DmpNavigationTree)表控制层
 *
 * @author Bellamy
 * @since 2020-12-29 15:08:17
 */
@RestController
@RequestMapping("/dmpNavigationTree")
@Api(tags = "DMP资源导航树")
public class DmpNavigationTreeController {
    /**
     * 服务对象
     */
    @Autowired
    private DmpNavigationTreeService dmpNavigationTreeService;

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/selectOne")
    @ApiOperation(value = "通过主键查询单条数据", notes = "通过主键查询单条数据")
    public DmpNavigationTree selectOne(Integer id) {
        return this.dmpNavigationTreeService.queryById(id);
    }

    /**
     * 列表查询DMP资源导航树
     *
     * @param dmpNavigationTreeRequest
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/findList")
    @ApiOperation(value = "列表查询DMP资源导航树", notes = "列表查询DMP资源导航树")
    public BaseBeanResponse<DmpNavigationTreeDto> findList(@RequestBody DmpNavigationTreeRequest dmpNavigationTreeRequest, HttpServletRequest httpRequest) {
        BaseBeanResponse<DmpNavigationTreeDto> baseBeanResponse = new BaseBeanResponse<DmpNavigationTreeDto>();
        try {
            baseBeanResponse = dmpNavigationTreeService.findList(dmpNavigationTreeRequest, httpRequest);
        } catch (Exception e) {
            baseBeanResponse.setMessage("查询失败");
            baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
            e.printStackTrace();
        }

        return baseBeanResponse;
    }

    /**
     * 新增DMP资源导航树
     *
     * @param dmpNavigationTreeRequest
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/add")
    @ApiOperation(value = "新增DMP资源导航树", notes = "新增DMP资源导航树")
    public BaseBeanResponse<DmpNavigationTree> add(@RequestBody DmpNavigationTree dmpNavigationTree, HttpServletRequest httpRequest) throws Exception {
        BaseBeanResponse<DmpNavigationTree> baseBeanResponse = new BaseBeanResponse<DmpNavigationTree>();
        
        //校验参数
        //
        
        //树名称去重
        DmpNavigationTreeRequest dmpNavigationTreeRequest = new DmpNavigationTreeRequest();
        dmpNavigationTreeRequest.setName(dmpNavigationTree.getName());
        dmpNavigationTreeRequest.setProjectId(dmpNavigationTree.getProjectId());
        BaseBeanResponse<DmpNavigationTreeDto> baseBeanResponseRe = dmpNavigationTreeService.findList(dmpNavigationTreeRequest, httpRequest);
        if (baseBeanResponseRe.getDatas() != null && baseBeanResponseRe.getDatas().size() > 0) {
            baseBeanResponse.setCode(StatuConstant.CODE_ERROR_PARAMETER);
            baseBeanResponse.setMessage("树名称不能重复");
            return baseBeanResponse;
        }
        try {
            DmpNavigationTree dmpNavigationTreeDb = dmpNavigationTreeService.insert(dmpNavigationTree);
            baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
            baseBeanResponse.setMessage("新增成功");
            baseBeanResponse.setData(dmpNavigationTreeDb);
        } catch (Exception e) {
            baseBeanResponse.setMessage("新增失败");
            baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
            e.printStackTrace();
        }

        return baseBeanResponse;
    }

    /**
     * 删除DMP资源导航树
     *
     * @param id
     * @return
     */
    @MethodCallLogPrint
    @RequestMapping(method = RequestMethod.GET, value = "/deleteById")
    @ApiOperation(value = "删除DMP资源导航树", notes = "删除DMP资源导航树")
    @ApiImplicitParam(name = "id", value = "DMP资源导航树主键")
    public BaseResponse deleteById(@RequestParam(name = "id", required = true) Integer id, HttpServletRequest httpRequest) {
        BaseResponse baseResponse = new BaseResponse();
        try {
            boolean flag = dmpNavigationTreeService.deleteById(id);
            if (flag) {
                baseResponse.setMessage("删除成功");
                baseResponse.setCode(StatuConstant.SUCCESS_CODE);
            } else {
                baseResponse.setMessage("删除失败");
                baseResponse.setCode(StatuConstant.FAILURE_CODE);
            }
        } catch (Exception e) {
            baseResponse.setMessage("删除失败");
            baseResponse.setCode(StatuConstant.FAILURE_CODE);
            e.printStackTrace();
        }

        return baseResponse;
    }

    /**
     * 修改DMP资源导航树
     *
     * @param dmpNavigationTreeRequest
     * @return
     */
    @MethodCallLogPrint
    @RequestMapping(method = RequestMethod.POST, value = "/edit")
    @ApiOperation(value = "修改DMP资源导航树", notes = "修改DMP资源导航树")
    public BaseBeanResponse<DmpNavigationTree> edit(@RequestBody DmpNavigationTree dmpNavigationTree, HttpServletRequest httpRequest) {
        BaseBeanResponse<DmpNavigationTree> baseBeanResponse = new BaseBeanResponse<DmpNavigationTree>();
        try {
            DmpNavigationTree dmpNavigationTreeDb = dmpNavigationTreeService.update(dmpNavigationTree);
            baseBeanResponse.setMessage("修改成功");
            baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
            baseBeanResponse.setData(dmpNavigationTreeDb);
        } catch (Exception e) {
            baseBeanResponse.setMessage("修改失败");
            baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
            e.printStackTrace();
        }

        return baseBeanResponse;
    }
}